@@ -1,7 +1,8 @@
 multinom.nb <- function(xnew, x, ina) {
-  nu <- tabulate(ina)
+  ni <- tabulate(ina)
+  ni <- ni[ni > 0]
   x <- x / Rfast::rowsums(x)  ## normalizes the data, so that each observation sums to 1
-  m <- rowsum(x, ina) / nu
+  m <- rowsum(x, ina) / ni
   score <- tcrossprod( xnew, log(m) )
   rowMaxs(score)
 }
\ No newline at end of file
