@@ -5,7 +5,7 @@ ompr <- function (y, x, method = "BIC", tol = 2 ) {
     ind <- 1:d
     m <- sum(y) / n
     y <- y - m
-    x <- standardise(x)
+    x <- eachrow(x, sqrt( colsums(x^2) ), oper="/")
     ######### SSE
     if ( method == "sse" ) {
       rho <- Var(y) * (n - 1)
@@ -17,18 +17,18 @@ ompr <- function (y, x, method = "BIC", tol = 2 ) {
       ind[sel] <- 0
       r[sel] <- 0
       i <- 2
-      while ((rho[i - 1] - rho[i])/(rho[i - 1]) > tol) {
+      while ( (rho[i - 1] - rho[i])/(rho[i - 1]) > tol  &  i < n ) {
         i <- i + 1
         r[sela] <- 0
         r[ind] <- cor(res, x[, ind])
         sel <- which.max(abs(r))
         sela <- c(sela, sel)
-        res <- .lm.fit(x[, sela], res)$residuals
+        res <- .lm.fit(x[, sela], y)$residuals
         rho[i] <- sum(res^2)
         ind[sela] <- 0
       }
-	  len <- length(sela)
-      info <- cbind(sela, rho[1:len])
+	len <- length(sela)
+      info <- cbind(c(0, sela[-len]), rho[1:len])
       colnames(info) <- c("Vars", "|sse|")
     ######### BIC
     } else if ( method == "BIC" ) {
@@ -42,44 +42,45 @@ ompr <- function (y, x, method = "BIC", tol = 2 ) {
       ind[sel] <- 0
       r[sel] <- 0
       i <- 2
-      while ( rho[i - 1] - rho[i] > tol ) {
+      while ( rho[i - 1] - rho[i] > tol & i < n ) {
         i <- i + 1
         r[sela] <- 0
         r[ind] <- cor(res, x[, ind])
         sel <- which.max(abs(r))
         sela <- c(sela, sel)
-        res <- .lm.fit(x[, sela], res)$residuals
+        res <- .lm.fit(x[, sela], y)$residuals
         rho[i] <- n * log( sum(res^2)/n ) + (i + 1) * log(n)
         ind[sela] <- 0
       }
 	len <- length(sela)
-      info <- cbind(sela, rho[1:len] + con)
+      info <- cbind(c(0, sela[-len]), rho[1:len] + con)
       colnames(info) <- c("Vars", "BIC")
     ######### adjusted R-square
     } else if (method == "ar2") {
+      down <- Var(y) * (n - 1)
       rho <- 0
       r <- cor(y, x)
       sel <- which.max( abs(r) )
       sela <- sel
       res <- .lm.fit(x[, sel, drop = FALSE], y)$residuals
-      r2 <- 1 - res^2
+      r2 <- 1 - sum(res^2)/down
       rho[2] <- 1 - (1 - r2) * (n - 1)/(n - 2)
       ind[sel] <- 0
       r[sel] <- 0
-      i <- 2
-      while ( rho[i] - rho[i - 1] > tol ) {
+	i <- 2
+      while ( rho[i] - rho[i - 1] > tol & i < n ) {
         i <- i + 1
         r[sela] <- 0
         r[ind] <- cor(res, x[, ind])
         sel <- which.max(abs(r))
         sela <- c(sela, sel)
-        res <- .lm.fit(x[, sela], res)$residuals
-        r2 <- 1 - res^2
+        res <- .lm.fit(x[, sela], y)$residuals
+        r2 <- 1 - sum(res^2)/down
         rho[i] <- 1 - (1 - r2) * (n - 1)/(n - i - 1)
         ind[sela] <- 0
       }
 	len <- length(sela)
-      info <- cbind(sela, rho[1:len])
+      info <- cbind(c(0, sela[-len]), rho[1:len])
       colnames(info) <- c("Vars", "adjusted R2")
     }
     info
