@@ -1,34 +1,33 @@
-univglms <-function (y, x, oiko = NULL, logged = FALSE) {
+univglms <- function (y, x, oiko = NULL, logged = FALSE) {
     dm <- dim(x)
     n <- dm[1]
     d <- dm[2]
     if (is.null(oiko)) {
         if (length(sort_unique(y)) == 2) {
-          oiko = "binomial"
-        } else if (sum(round(y) - y) == 0) {
-          oiko = "poisson"
-        } else oiko = "normal"
+            oiko = "binomial"
+        }
+        else if (sum(round(y) - y) == 0) {
+            oiko = "poisson"
+        }
+        else oiko = "normal"
     }
     if (oiko == "binomial") {
         p <- sum(y)/n
-        ini <-  -2 * ( n * p * log(p) + (n - n * p) * log(1 - p) )
+        ini <- -2 * (n * p * log(p) + (n - n * p) * log(1 - p))
         mod <- logistic_only(x, y)
         stat <- ini - mod
         pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = logged)
     }
     else if (oiko == "poisson") {
         m <- sum(y)/n
-        ini <- 2 * sum( y * log(y), na.rm = TRUE ) - 2 * n * m * log(m)
+        ini <- 2 * sum(y * log(y), na.rm = TRUE) - 2 * n * m * 
+            log(m)
         mod <- poisson_only(x, y)
         stat <- ini - mod
         pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = logged)
     }
     else if (oiko == "normal") {
-        mn_mx <- min_max(y)
-        if (mn_mx[1] > 0 & mn_mx[2] < 1) {
-            y <- log(y/(1 - y))
-        }
-        rho <- as.vector( cor(y, x) )
+        rho <- as.vector(cor(y, x))
         sqdof <- sqrt(n - 2)
         stat <- rho * sqdof/sqrt(1 - rho^2)
         if (logged) {
@@ -37,6 +36,14 @@ univglms <-function (y, x, oiko = NULL, logged = FALSE) {
         }
         else pval <- 2 * pt(abs(stat), n - 2, lower.tail = FALSE)
     }
+    else if (oiko == "quasipoisson") {
+        m <- sum(y)/n
+        ini <- 2 * sum(y * log(y), na.rm = TRUE) - 2 * n * m * 
+            log(m)
+        mod <- quasi.poisson_only(x, y)
+        stat <- (ini - mod[1, ])/mod[2, ]
+        pval <- pf(stat, 1, n - 2, lower.tail = FALSE, log.p = logged)
+    }
     result <- cbind(stat, pval)
     colnames(result) <- c("stat", "pvalue")
     if (is.null(colnames(x))) {
