@@ -8,8 +8,28 @@
 #include <fstream>
 #include <dirent.h>
 
-using namespace std;
-using namespace Rcpp;
+using std::vector;
+using std::string;
+using std::ifstream;
+
+//[[Rcpp::plugins(cpp11)]]
+
+void print_error();
+
+template<class T,class... Args>
+void print_error(T values,Args... args){
+	Rcpp::Rcout<<values<<"\n";
+	print_error(args...);
+}
+
+
+//#define PRINT_ERRORS
+#ifdef PRINT_ERRORS
+#define DEBUG(message) (print_error(message))
+#else
+#define DEBUG(message);
+#endif
+
 
 vector<string> split_words(string);
 void writeFile(vector<string>,string);
@@ -24,8 +44,11 @@ vector<string> find_duplis(vector<string>);
 bool is_example(const char *,int);
 bool get_example(ifstream&,string&);
 vector<string> read_directory(string);
-string read_example(ifstream &file,int& long_lines);
+string read_example(ifstream &,int&);
 bool binary_help(vector<string>::iterator,vector<string>::iterator,string&,vector<string>::iterator&);
 void dont_read_man(vector<string>&,vector<string>&);
-
+vector<string> read_usage(ifstream &);
+string read_function_from_r_file(ifstream &);
+void remove_spaces(string&);
+bool find_string(string& s,const char *cs);
 #endif
